#!/usr/bin/env python3

import os
import sys

from psycopg import connect
from psycopg.errors import OperationalError

URL = os.getenv('DATABASE_URL')
if URL is None or URL == '':
    print('No DATABASE_URL specified!', file=sys.stderr)
    sys.exit(2)

try:
    if URL.startswith('postgis://'):
        URL = 'postgresql://' + URL[len('postgis://') :]
    connect(URL)

except OperationalError as err:
    print('ERROR', file=sys.stderr)
    print('    ', err, sep='', file=sys.stderr)
    sys.exit(1)
except Exception as err:  # pylint: disable=W0718
    print('UNKNOWN', file=sys.stderr)
    print('    ', err, sep='', file=sys.stderr)
    sys.exit(3)
