from django.conf import settings

from core.models.conference import Conference


def get_conference(request):
    conference_id = request.session.get('conference')
    if conference_id is None:
        try:
            conference = Conference.objects.filter(is_public=True).first()
            request.session['conference'] = conference.slug
        except Conference.DoesNotExist:
            return None
    else:
        try:
            conference = Conference.objects.accessible_by_user(request.user).get(slug=conference_id)
        except Conference.DoesNotExist:
            request.session['conference'] = None

    return conference


def extend_context(request, context, conference=None):
    if conference is None:
        conference = get_conference(request)
    conference_list = Conference.objects.accessible_by_user(request.user).all()

    context.update(
        {
            'LANGUAGES': settings.LANGUAGES,
            'conference': conference,
            'conferences': conference_list,
            'has_pages': request.user.has_pages(conference) if request.user.is_authenticated else False,
        }
    )

    return context
