from core.models.assemblies import Assembly
from core.models.rooms import Room
from core.models.users import PlatformUser


class HangarIntegration:
    def __init__(self, url):
        self._url = url

    def is_available(self):
        return self._url is not None

    def can_create_for_assembly(self, assembly: Assembly):
        assert assembly is not None

        # limit to one instance per assembly
        existing = assembly.rooms.filter(room_type=Room.RoomType.HANGAR).exists()
        return not existing

    def create_room(self, room: Room):
        assert room is not None and room.room_type == Room.RoomType.HANGAR and room.backend_status == Room.BackendStatus.NEW
        # status is managed externally

    def remove_room(self, room: Room):
        assert room is not None and room.room_type == Room.RoomType.HANGAR

        # cannot be done here, trigger "contact technician" message
        return False

    def room_status(self, room: Room):
        assert room is not None and room.room_type == Room.RoomType.HANGAR

        return room.backend_status

    def join_room(self, room: Room, user: PlatformUser):
        assert room is not None and room.room_type == Room.RoomType.HANGAR
        assert user is not None

        url = self._url.format(
            assembly_slug=room.assembly_slug,
            room_id=room.id,
            username=user.username,
        )
        return url
