import time

from django.core.management.base import BaseCommand
from django.db import transaction

from core.integrations import BigBlueButton, IntegrationError
from core.models import Conference, Room


class Command(BaseCommand):
    def add_arguments(self, parser):
        parser.add_argument(
            '-a',
            '--all',
            action='store_true',
            help='Revisit all Rooms, not just failing ones',
        )

    def handle(self, *args, **options):
        revisit_active = options['all']
        conf = Conference.objects.current_conference

        start = time.time()
        n_fail = 0
        n_healthy = 0

        for room in Room.objects.filter(conference=conf, room_type=Room.RoomType.BIGBLUEBUTTON):
            if room.backend_status in {Room.BackendStatus.NEW, Room.BackendStatus.ERROR, Room.BackendStatus.SETUP}:
                n_fail += 1
                try:
                    with transaction.atomic():
                        BigBlueButton.create_room(room)
                        room.save()
                except IntegrationError as e:
                    print(f'Refreshing room {room!s} failed: {e!s}')

            elif revisit_active and room.backend_status in {Room.BackendStatus.ACTIVE, Room.BackendStatus.FULL}:
                n_healthy += 1
                try:
                    with transaction.atomic():
                        BigBlueButton.room_status(room)
                        room.save()
                except IntegrationError as e:
                    print(f'Refreshing room {room!s} failed: {e!s}')

        run_time = time.time() - start
        print(f"Revisited {n_fail} failing rooms {f'and {n_healthy} healthy ones'} in {run_time} Seconds.")
