import logging
import re

from django.conf import settings
from django.contrib import messages
from django.utils import timezone

logger = logging.getLogger(__name__)


class TimezoneMiddleware:
    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        if request.user.is_authenticated:
            timezone.activate(request.user.timezone)
            if request.user.admin_notification:
                messages.warning(request, request.user.admin_notification)
        else:
            timezone.deactivate()
        return self.get_response(request)


V6_WITH_V4_PREFIX_REGEX = re.compile(r'::ffff:(\d+\.\d+\.\d+\.\d+)')


class SetRemoteAddrMiddleware:
    def __init__(self, get_response):
        self.get_response = get_response

    def __call__(self, request):
        lookup_header = settings.CLIENT_IP_HEADER
        if lookup_header:
            try:
                real_ip = request.META[lookup_header]
            except KeyError:
                logger.debug('Could not load client ip from %r in request from %r. Misconfigured Proxy?', lookup_header, request.META['REMOTE_ADDR'])
            else:
                # HTTP_X_FORWARDED_FOR can be a comma-separated list of IPs. The
                # client's IP will be the first one.
                real_ip = real_ip.split(',')[0].strip()
                m = V6_WITH_V4_PREFIX_REGEX.match(real_ip)
                if m:
                    real_ip = m.group(1)
                request.META['REMOTE_ADDR'] = real_ip

        return self.get_response(request)
