from django.contrib.contenttypes.fields import GenericForeignKey
from django.contrib.contenttypes.models import ContentType
from django.db import models


class MetaTypes(models.TextChoices):
    USER_SLUG = 'user'
    PAGE_SLUG = 'page'
    LINKED_URL = 'url'


class MarkdownMeta(models.Model):
    class Meta:
        unique_together = [['src_type', 'src_object_id', 'dst_type', 'dst_object']]

    src_type = models.ForeignKey(ContentType, on_delete=models.CASCADE, related_name='+')
    src_object_id = models.UUIDField()
    src = GenericForeignKey('src_type', 'src_object_id')

    dst_type = models.CharField(max_length=15, choices=MetaTypes.choices)
    dst_object = models.TextField()
