// wait until document is loaded
var fpReady = (callback) => {
  if (document.readyState != "loading") callback();
  else document.addEventListener("DOMContentLoaded", callback);
};

fpReady(() => {
  // one click listener to rule them all :)
  document.addEventListener("click", function onclicked(e) {
    documentClicked(e);
  });
  // check for the URL hash and open modal if hash is present
  if (window.location.hash) {
    showModal2(window.location.hash.substr(1));
  }
});

function documentClicked(e) {
  if (e.target.dataset.eventid) {
    e.preventDefault();
    showModal2(e.target.dataset.eventid);
  }

  if (e.target.classList.contains("modal-close")) {
    e.preventDefault();
    removeFahrplanModal();
  }
}

function showModal2(event_id) {
  let data_el = document.getElementById(event_id);
  if (!data_el) {
    return;
  }
  let data = JSON.parse(data_el.innerText);
  if (!data) {
    return;
  }
  let modal = document.createElement("div");
  window.location.hash = event_id;
  modal.classList.add("rc3-fahrplan__modal-box");
  modal.innerHTML = `
    <div class="modal show modal-close" tabindex="-1" style="display:block;">
        <div class="modal-dialog modal-lg">
          <div class="modal-content border p-5 rc3-fahrplan__modal-content">
            <div class="modal-header">
              <h3 class="rc3-fahrplan__modal-title modal-title">${data.title}</h3>
              <button type="button" class="btn-close btn-close-white close modal-close rc3-fahrplan__modal-close" data-dismiss="modal" aria-label="Close">
              </button>
            </div>
            <div class="modal-body mt-4 pt-0 rc3-fahrplan__modal-body">
              ${eventContent(data)}
            </div>
          </div>
        </div>
    </div>
    `;
  document.body.appendChild(modal);
}

function eventContent(data) {
  let content =
    `
    <dl class="rc3-fahrplan__modal-data">
        <dt>Start:</dt>
        <dd class=""><time datetime="${data.schedule_start}">${data.schedule_start}</time></dd>

        <dt>Duration:</dt>
        <dd class=""><time datetime="${data.schedule_duration}">${data.schedule_duration}</time></dd>

        <dt>Room:</dt>
        <dd class="">${data.room_name}</dd>

    ` +
    (data.track_name && data.track_name != "None"
      ? `
        <dt>Track:</dt>
        <dd class="">${data.track_name}</dd>`
      : "") +
    `

        <dt>Language:</dt>
        <dd class="">${data.language}</dd>

        <dt>Speakers:</dt>
        <dd class="">${data.speakers}</dd>

        <dt>Video:</dt>
        <dd class="">
            <a class="a" href="https://streaming.media.ccc.de/rc3/" title="streams" target="_blank">live</a>
            <a class="a" href="https://streaming.media.ccc.de/rc3/relive/${data.id}" title="relive" target="_blank">relive</a>
            <a class="a" href="https://media.ccc.de/v/${data.id}" title="recording" target="_blank">recording</a>
        </dd>
        `;
  if (data.link != null) {
    content += `
        <dt>Origin:</dt>
        <dd class=""><a class="a" href="${data.link}" alt="Details" target="_blank">${data.link}</a></dd>`;
  }

  content += `
    </dl>`;

  if (data.abstract) {
    content += `
        <hr class="my-4">
        <p>${data.abstract}</p>`;
  }

  content += `
        <hr class="my-4">
        <div class="rc3-markdown">${data.description_html}</div>`;

  return content;
}

function removeFahrplanModal() {
  window.location.hash = "_";
  document.querySelectorAll(".rc3-fahrplan__modal-box").forEach(function (el) {
    console.log("should remove");
    el.remove();
  });
}
